"use strict";Object.defineProperty(exports, "__esModule", {value: true}); function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { newObj[key] = obj[key]; } } } newObj.default = obj; return newObj; } } function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }// src/index.ts
var _pluginutils = require('@rollup/pluginutils');
var _changecase = require('change-case'); var changeCase = _interopRequireWildcard(_changecase);
var _esmodulelexer = require('es-module-lexer');
var _magicstring = require('magic-string'); var _magicstring2 = _interopRequireDefault(_magicstring);
var _path = require('path'); var _path2 = _interopRequireDefault(_path);
var _vite = require('vite');
var src_default = (options) => {
  const {
    include = ["**/*.vue", "**/*.ts", "**/*.js", "**/*.tsx", "**/*.jsx"],
    exclude = "node_modules/**",
    libs = []
  } = options;
  const filter = _pluginutils.createFilter.call(void 0, include, exclude);
  return {
    name: "vite:style-import",
    async transform(code, id) {
      if (!filter(id) || !needTransform(code, libs))
        return code;
      if (!code) {
        return code;
      }
      await _esmodulelexer.init;
      let imports = [];
      try {
        imports = _esmodulelexer.parse.call(void 0, code)[0];
      } catch (e) {
        console.log(e);
      }
      if (!imports.length) {
        return code;
      }
      let s;
      const str = () => s || (s = new (0, _magicstring2.default)(code));
      for (let index = 0; index < imports.length; index++) {
        const {s: start, e: end, se, ss} = imports[index];
        const name = code.slice(start, end);
        if (!name) {
          continue;
        }
        const lib = getLib(name, libs);
        if (!lib) {
          continue;
        }
        const importStr = code.slice(ss, se);
        const exportVariables = transformImportVar(importStr);
        const importStrList = transformLibCss(lib, exportVariables);
        str().prepend(importStrList.join(""));
      }
      return {
        code: str().toString()
      };
    }
  };
};
function transformLibCss(lib, exportVariables) {
  const {libraryName, resolveStyle, esModule, libraryNameChangeCase = "paramCase"} = lib;
  if (!resolveStyle || typeof resolveStyle !== "function" || !libraryName) {
    return [];
  }
  const set = new Set();
  for (let index = 0; index < exportVariables.length; index++) {
    const name = getChangeCaseFileName(exportVariables[index], libraryNameChangeCase);
    let importStr = resolveStyle(name);
    if (esModule) {
      importStr = resolveNodeModules(importStr);
    }
    set.add(`import '${importStr}';`);
  }
  return Array.from(set);
}
function transformImportVar(importStr) {
  if (!importStr) {
    return [];
  }
  const exportStr = importStr.replace("import", "export").replace(/\s+as\s+\w+,?/g, ",");
  let exportVariables = [];
  try {
    exportVariables = _esmodulelexer.parse.call(void 0, exportStr)[1];
  } catch (error) {
    console.error(error);
  }
  return exportVariables;
}
function getLib(libraryName, libs) {
  return libs.find((item) => item.libraryName === libraryName);
}
function getChangeCaseFileName(importedName, libraryNameChangeCase) {
  try {
    return changeCase[libraryNameChangeCase](importedName);
  } catch (error) {
    return importedName;
  }
}
function needTransform(code, libs) {
  return !libs.every(({libraryName}) => {
    return !new RegExp(`('${libraryName}')|("${libraryName}")`).test(code);
  });
}
function resolveNodeModules(...dir) {
  return _vite.normalizePath.call(void 0, _path2.default.join(process.cwd(), "node_modules", ...dir));
}


exports.default = src_default;
